#!/bin/bash

SCRIPT_PATH="$(
  cd "$(dirname "$0")" >/dev/null 2>&1 || exit
  pwd -P
)"

LOG_FILE=$(basename "$0" .sh).log

for i in "$@"; do
  case $i in
  -p=* | --profile=*)
    AM2CM_SERVER_PROFILE=${i#*=}
    ;;
  -j=* | --jdbc-drivers-dir=*)
    JDBC_DRIVERS_DIR=${i#*=}
    ;;
  -jb=* | --jdbc-drivers-backup-dir=*)
      JDBC_DRIVERS_BACKUP_DIR=${i#*=}
      ;;
  -h | --help)
    HELP=true
    ;;

  esac

done

__usage="
 Usage: $(basename "$0") [options]
 Options:
    -j, --jdbc-drivers-dir: Set the jdbc-drivers dir
    -jb, --jdbc-drivers-backup-dir: Set the jdbc-drivers backup dir
    -iv, --image-version: Set the version tag for the docker image
    -p, --profile: Set the active profile(s) for the am2cm-server
    -h, --help: Print this help
 "

if [ "${HELP}" = true ]; then
  echo "$__usage"
  exit 0
fi

if [ -z "${AM2CM_SERVER_PROFILE}" ]; then
  echo "--profile must be specified!" | tee -a "$LOG_FILE"
  echo "$__usage" | tee -a "$LOG_FILE"
  exit 1
fi

if [ -z "${JDBC_DRIVERS_DIR}" ]; then
  echo "--jdbc-drivers-dir must be specified!" | tee -a "$LOG_FILE"
  echo "$__usage" | tee -a "$LOG_FILE"
  exit 1
fi

if [ -z "${JDBC_DRIVERS_BACKUP_DIR}" ]; then
  echo "--jdbc-drivers-backup-dir must be specified!" | tee -a "$LOG_FILE"
  echo "$__usage" | tee -a "$LOG_FILE"
  exit 1
fi

# copy jdbc drivers
echo "copying ${JDBC_DRIVERS_BACKUP_DIR} to ${JDBC_DRIVERS_DIR} " | tee -a "$LOG_FILE"
#mkdir -p "${JDBC_DRIVERS_DIR}"
cp -n -r "${JDBC_DRIVERS_BACKUP_DIR}" "${JDBC_DRIVERS_DIR}"

cp -nr /tmp/python_and_packages/* "$AM2CM_ROOT"

# start server
am2cm-server.sh --profile="${AM2CM_SERVER_PROFILE}" --start --docker-mode
